
#include "EaEpaper.h"

#define EA_IMG_BUF_SZ (5808) // 264 x 176 / 8 = 5808

#define LM75A_ADDRESS (0x92) // 0x49 << 1
#define LM75A_CMD_TEMP 0x00

static uint8_t _oldImage[EA_IMG_BUF_SZ];


DigitalOut led1(LED1);
DigitalOut led2(LED2);
DigitalOut led3(LED3);
DigitalOut led4(LED4);


EaEpaper::EaEpaper() : 
    epd_(EPD_2_7,    
          p9,  // panel_on_pin
          p10, // border_pin
          p11, // discharge_pin
          p26, // pwm_pin
          p12, // reset_pin
          p13, // busy_pin
          p8,  // chip_select_pin
          p5,  // mosi
          p6,  // miso
          p7),  // sck    
    i2c_(p28, p27)      
{   
    memset(_oldImage, 0, EA_IMG_BUF_SZ);                                        
}



void EaEpaper::clear()
{   
    epd_.begin();
    epd_.setFactor(readTemperature()/100);
    epd_.clear();    
    epd_.end();
     
    memset(_oldImage, 0, EA_IMG_BUF_SZ);
}

void EaEpaper::write(const uint8_t *image)
{
    epd_.begin();
    epd_.setFactor(readTemperature()/100);
    epd_.image(_oldImage, image);
    epd_.end();
    
    memcpy(_oldImage, image, EA_IMG_BUF_SZ);
}


int32_t EaEpaper::readTemperature()
{
    char buf[2];
    int32_t t = 0;
    char reg = LM75A_CMD_TEMP;
    
    i2c_.write(LM75A_ADDRESS, &reg, 1);
    i2c_.read(LM75A_ADDRESS, buf, 2);   
    
    t = ((buf[0] << 8) | (buf[1])); 
    
    return ((t * 100) >> 8);
}


